﻿//***************************************************************************
// (C) 2011 Avery Weigh-Tronix, LLC. 
//***************************************************************************
// TITLE: WTCommSO ActiveX DLL OPOS Server Object Test Program
// DESCR: This is the project source code for the WTScale Test program. 
//        The project was written in C# using Visual Studio 2008 on a
//        Windows 7 (64-bit) computer.
//        Target platform is x86 so it should run on Win XP (32/64-bit) as
//        well as Win 7 (32/64-bit) that have .NET Framework v2.0 or newer.
//        
//        This program was written and is provided so as to show that the
//        legacy WTScaleSO.DLL can be used in a newer development environment
//        than it was originally developed in (i.e. VB6 SP6 on WinMe).
//        Due to the layered architecture of OPOS, the application will talk
//        only to the OPOS Scale Device Common Control Object (CCO). It is the
//        job of the CCO to talk to the WTScale SO Service Object (SO). And,
//        only the SO talks directly to the scale using the serial communic-
//        ations port.
//
// (C)Copyright 2011 Avery Weigh-Tronix, LLC.
//
// Contacts:
// Sales:	sales@salterbrecknell.com
//       	1-800-637-0529
//
// Service:	service@salterbrecknell.com
//      	1-800-242-2807
//
// Disclaimer:
// This test/demo program is provided as a courtesy to customers of Avery 
// Weigh-Tronix for their personal use.
//
// NO WARRANTIES: The free-of-charge software is provided “as-is” with no 
// warranties expressed or implied.
// NO LIABILITY: To the maximum extent permitted by applicable law, in no 
// event shall Avery Weigh-Tronix, its' suppliers or subsidiaries be liable 
// for any damages whatsoever (including without limitation, damages for 
// loss of business profits, business interruption, loss of business infor-
// mation, or other pecuniary loss) arising out of the installation, use or
// inability to use the software provided, even if Avery Weigh-Tronix has 
// been advised of the possibility of such damages.
// 
// This product was developed for Avery Weigh-Tronix by:
// www.vtxpro.com 
// (C)2011 Vertex Programming -- Santa Rosa, CA
//
// PROGRAMMERS NOTES:
//  1) This app originally used .NET Framework v2.0 but you can use any version.
//  2) This app was originally deployed using ClickOnce technology.
//  3) ClickOnce (on .NET Framework v2.0) does not support placing a shortcut to
//     the application on the desktop at install time. So, a CreateDesktopShortcut()
//     function was added to do this. If you use newer .NET Frameworks that do support
//     desktop icons, then you can omit this function and related namespaces.
//  4) To add a reference to the OPOSScale.ocx CCO:
//     * Right-Click on References in the Solution Explorer.
//     * Click on 'Add Reference...'
//     * Click on the Browse tab.
//     * Browse to find the OPOSScale.OCX file. 
//       On Windows 7 it is usually located at c:\Windows\SysWoW64\OPOSScale.OCX but
//       it could be located in the c:\Program Files (x86)\Avery Weigh-Tronix\.. folder 
//       or one of its sub-folders. Therefore, it is easiest to first do a search of 
//       your computer to find the exact location of the OPOSScale.OCX file.
//     * Click OK to finish.
//     * OposScale_1_6_Lib should now be listed in the References list in Solution Explorer.
//  5) Add the namespace reference at the top of the program as follows:
//     using OposScale_1_6_Lib;
//     Since the CCO has a constructor, you may now declare an instance of the OPOSScaleClass
//     as you would any other class.
//  6) To add the CCO ActiveX control to the Toolbox:
//     Alternatively, you can add the CCO to the toolbox. This CCO does not have a user interface
//     for setting properties etc, but it can be used as any other control by dragging from the
//     toolbox to a form and then setting properties in the Properties window.
//     * Click on the Toolbox tab to open the Toolbox window.
//     * Right-Click on the 'All Windows Forms' section header of the Toolbox window.
//     * Click on 'Choose Items...'
//     * In the Choose Toolbox Items window, click on the COM Components tab.
//     * Scroll down and check the box next to: OPOS Scale Control 1.6.000 [Public, by CRM/RCS-Dayton]
//     * Click OK.
//     * The OPOS Scale Control 1.6.000 should now be added to the Toolbox towards the 
//       bottom of the All Windows Forms section.
//       If it does not show up, save all files in your project, exit Visual Studio and
//       then open your project again and it should be in the Toolbox.
//     * AxOposScale_1_6_Lib should now be listed in the References list in Solution Explorer.
//       The first object created by dragging/dropping will be called axOPOSScale1
//  7) To prevent runtime error: "Class not registered..."
//     Make sure to set Platform Target: x86 in Project Properties - Build - General
//  8) "LoaderLock was detected" warning message.
//     This warning message is an artifact from legacy components being run on newer Frameworks.
//     Microsoft confirms this issue and recommends simply to turn off the LoaderLock 
//     exception under the Managed Debugging Assistants section.
//  9) Runtime Executable Error (Scale profile name not found in system registry) :
//     When your application is built, deployed to a Windows 7 computer and the executable is launched, 
//     you might encounter a runtime error when attempting to Connect even when you have a proper Scale
//     Profile name entered. This error occurs because the application is structured to access the standard
//     registry whereas the legacy CCO needs to get these from the virtualized registry storage area in 
//     Windows 7. 
//     Note: this error will not occur in the debug mode as registry access in Win 7 are automatically 
//     virtualized for legacy applications.
//     This error will be indicated when the Connect button is pressed by the following status
//     Open returned: 109		OPOS_E_NOEXIST
//     OpenResult code: 302		OPOS_OR_REGBADNAME
//     Open Service Object: FAIL
//
//     To remedy this runtime problem, the applications manifest file must be modified slightly so as to
//     let the application (with legacy CCO and SO) access the virtualized registry. A means is provided
//     in the application manifest to  use Registry Virtualization to support this backward-compatibility.
//     In the Solution Explorer double-click on the app.manifest file under the Properties section.
//     The app.manifest file is an XML file and it includes commented instructions on utilizing Registry
//     Virtualization which is to delete the requestedExecutionLevel node. 
//     The requestedExecutionLevel node line effectively removed by commenting the line out using standard
//     XML comment markers.

using System;
using System.Windows.Forms;

using System.Deployment.Application;        // for desktop application icon (see note 3)
using System.Reflection;                    // for desktop application icon (see note 3)

using OposScale_1_6_Lib;                    // to access the OPOS Scale CCO 

namespace WTScaleSO_Test
{
    public partial class MAIN : Form
    {
        // This example uses a CCO that was dragged from the Toolbox to the main form.
        // If you prefer to instantiate the CCO programmatically then you may declare
        // the instance of the CCO as follows:
        //private OPOSScaleClass OPOSScale = new OPOSScaleClass();

        private bool isOpen;
        private bool isClaimed;
        private bool isEnabled;

        public MAIN()
        {
            // IMPORTANT: To prevent runtime error: "Class not registered..." make
            // sure to set Platform Target: x86 in Project Properties - Build - General

            InitializeComponent();
        }

        #region ClickOnce Desktop Shortcut
        // This will create an Application Reference file (a shortcut) on the users desktop
        // if they do not already have one when the program is loaded.
        // Check for them running the deployed version before doing this, so it doesn't kick
        // it when you're running it from within the Visual Studio IDE.
        private void CreateDesktopShortcut()
        {
            if (System.Deployment.Application.ApplicationDeployment.IsNetworkDeployed)
            {
                ApplicationDeployment ad = ApplicationDeployment.CurrentDeployment;
                if (ad.IsFirstRun)  //first time user has run the app since installation or update
                {
                    Assembly code = Assembly.GetExecutingAssembly();
                    string company = string.Empty;
                    string description = string.Empty;
                    if (Attribute.IsDefined(code, typeof(AssemblyCompanyAttribute)))
                    {
                        AssemblyCompanyAttribute ascompany =
                            (AssemblyCompanyAttribute)Attribute.GetCustomAttribute(code,
                            typeof(AssemblyCompanyAttribute));
                        company = ascompany.Company;
                    }
                    if (Attribute.IsDefined(code, typeof(AssemblyDescriptionAttribute)))
                    {
                        AssemblyDescriptionAttribute asdescription =
                            (AssemblyDescriptionAttribute)Attribute.GetCustomAttribute(code,
                            typeof(AssemblyDescriptionAttribute));
                        description = asdescription.Description;
                    }
                    if (company != string.Empty && description != string.Empty)
                    {
                        string desktopPath = string.Empty;
                        desktopPath = string.Concat(
                            Environment.GetFolderPath(Environment.SpecialFolder.Desktop),
                            "\\", description, ".appref-ms");
                        string shortcutName = string.Empty;
                        shortcutName = string.Concat(
                            Environment.GetFolderPath(Environment.SpecialFolder.Programs),
                            "\\", company, "\\", description, ".appref-ms");
                        System.IO.File.Copy(shortcutName, desktopPath, true);
                    }
                }
            }
        }
        #endregion


        private void MAIN_Load(object sender, EventArgs e)
        {
            textBoxCODescription.Text = OPOSScale.ControlObjectDescription;
            textBoxCOVersion.Text = OPOSScale.ControlObjectVersion.ToString();
        }

        private void buttonConnect_Click(object sender, EventArgs e)
        {
            // OPEN
            if (Open() == true)
            {
                WriteStatus("Open Service Object: SUCCESS");
                isOpen = true;
            }
            else
            {
                WriteStatus("Open Service Object: FAIL");
                isOpen = false;
            }

            // CLAIM
            if (ClaimDevice() == true)
            {
                WriteStatus("Claim Device: SUCCESS");
                isClaimed = true;
            }
            else
            {
                WriteStatus("Claim Device: FAIL");
                isClaimed = false;
            }

            // ENABLE
            if (DeviceEnabled() == true)
            {
                WriteStatus("Device Enabled: SUCCESS");
                isEnabled = true;
            }
            else
            {
                WriteStatus("Device Enabled: FAIL");
                isEnabled = false;
            }
        }

        private void buttonDisconnect_Click(object sender, EventArgs e)
        {
            // DISABLE
            OPOSScale.DeviceEnabled = false;
            WriteStatus("Device Disabled");
            isOpen = false;

            // RELEASE
            OPOSScale.ReleaseDevice();
            WriteStatus("Device Released");
            isClaimed = false;

            // CLOSE
            OPOSScale.Close();
            WriteStatus("Service Object Closed");
            isEnabled = false;
        }

        private void buttonReadWeight_Click(object sender, EventArgs e)
        {
            int weight;
            int readTimeout = 3000;
            int result;
            long uom;

            textBoxScaleData.Text = "";

            if (isOpen && isClaimed && isEnabled)
            {

                result = OPOSScale.ReadWeight(out weight, readTimeout);
                if (result == Opos.OPOS_SUCCESS)
                {
                    textBoxScaleData.Text = weight.ToString();
                    WriteStatus("ReadWeight command sent to scale: SUCCESS");

                    // Read units-of-measure
                    uom = OPOSScale.WeightUnit;

                    switch (uom)
                    {
                        case OposScal.SCAL_WU_GRAM:
                            WriteStatus("Weigh Units = GRAMS");
                            break;
                        case OposScal.SCAL_WU_KILOGRAM:
                            WriteStatus("Weigh Units = KILOGRAMS");
                            break;

                        case OposScal.SCAL_WU_OUNCE:
                            WriteStatus("Weigh Units = OUNCES");
                            break;

                        case OposScal.SCAL_WU_POUND:
                            WriteStatus("Weigh Units = POUNDS");
                            break;
                        default:
                            break;
                    }
                }
                else
                {
                    // If returned value is not OPOS_SUCCESS, the returned value, ResultCode and 
                    // ResultCodeExtended properties can be checked to determine the source of the failure.

                    textBoxScaleData.Text = "";
                    WriteStatus("ReadWeight command sent to scale: FAIL");
                }
            }
            else
            {
                MessageBox.Show("Unable to read weight from scale until Open, Claim and EnableDevice is successful");
            }
        }

        private void buttonZero_Click(object sender, EventArgs e)
        {
            int result;

            if (isOpen && isClaimed && isEnabled)
            {
                result = OPOSScale.ZeroScale();
                if (result == Opos.OPOS_SUCCESS)
                {
                    textBoxScaleData.Text = "";
                    WriteStatus("ZeroScale command sent to scale: SUCCESS");
                }
                else
                {
                    // If returned value is not OPOS_SUCCESS, the returned value, ResultCode and 
                    // ResultCodeExtended properties can be checked to determine the source of the failure.

                    WriteStatus("ZeroScale command sent to scale: FAIL");
                }
            }
            else
            {
                MessageBox.Show("Unable to zero scale weight until Open, Claim and EnableDevice is successful");
            }
        }

        // Attempt to 'Open' the scale service object for access.
        private bool Open()
        {
            if (textBoxProfileName.Text == "")
            {
                MessageBox.Show("You must first specify a profile name for the scale exactly as it was entered in the WTScale Administration program.");
                return false;
            }

            int result = OPOSScale.Open(textBoxProfileName.Text);
            if (result == Opos.OPOS_SUCCESS)
            {
                // Display service object info:
                textBoxSODescription.Text = OPOSScale.ServiceObjectDescription;
                textBoxSOVersion.Text = OPOSScale.ServiceObjectVersion.ToString();

                // Display device info:
                textBoxDeviceDescription.Text = OPOSScale.DeviceDescription;
                textBoxDeviceName.Text = OPOSScale.DeviceName;

                return true;
            }
            else
            {
                // Display returned value and error codes:
                WriteStatus("Open returned: " + result.ToString());
                WriteStatus("OpenResult code: " + OPOSScale.OpenResult.ToString());

                // Clear service object info:
                textBoxSODescription.Text = "";
                textBoxSOVersion.Text = "";

                // Clear device info:
                textBoxDeviceDescription.Text = "";
                textBoxDeviceName.Text = "";

                return false;
            }

        }

        // Attempt to 'Claim' the scale device.
        private bool ClaimDevice()
        {
            int claimTimeout = 3000;                         // mSec to wait for claim success
            int result = OPOSScale.ClaimDevice(claimTimeout);

            if (result == Opos.OPOS_SUCCESS)
                return true;
            else
                return false;
        }

        // Attempt to 'Enable' the scale device.
        private bool DeviceEnabled()
        {
            // Set the property:
            OPOSScale.DeviceEnabled = true;

            // Read property back from the service object:
            bool result = OPOSScale.DeviceEnabled;

            if (result == true)
                return true;
            else
                return false;
        }

        private void buttonClear_Click(object sender, EventArgs e)
        {
            textBoxStatus.Text = "";
        }

        private void WriteStatus(string text)
        {
            textBoxStatus.AppendText(text + "\n");
        }

        private void checkBoxAccept0Weight_Click(object sender, EventArgs e)
        {
            // This option allows setting a 'Vendor-Specific' (Avery Weigh-Tronix) command
            // that allows weight values of zero (i.e. 0.00) to be accepted as valid readings
            // from the scale.

            int intParam = 0;
            string stringParam = "";
            long result;

            if (checkBoxAccept0Weight.Checked == true)
                result = OPOSScale.DirectIO(WTCommands.WT_MfgCmd_0Wt_Valid, ref intParam, ref stringParam);
            else
                result = OPOSScale.DirectIO(WTCommands.WT_MfgCmd_0Wt_NotValid, ref intParam, ref stringParam);
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
           frmAbout about = new frmAbout();

           Assembly aAssembly = Assembly.GetExecutingAssembly();

           // get the product name from the assembly information
           {
              AssemblyTitleAttribute title;
              title = (AssemblyTitleAttribute)AssemblyTitleAttribute.GetCustomAttribute(aAssembly, typeof(AssemblyTitleAttribute));
              about.AboutProductName = title.Title;
           }

           // get the description from the assembly information
           {
              AssemblyDescriptionAttribute desc;
              desc = (AssemblyDescriptionAttribute)AssemblyDescriptionAttribute.GetCustomAttribute(aAssembly, typeof(AssemblyDescriptionAttribute));
              about.AboutDescription = desc.Description;
           }

           // get the product number information
           {
              about.AboutPartNumber = Application.ProductName;
           }

           // get the version number from the assembly information
           {
              Version version = Assembly.GetEntryAssembly().GetName().Version;
              about.AboutVersionNumber = String.Format("Version {0}.{1}.{2}.{3}", version.Major, version.Minor, version.Build, version.MinorRevision);
           }

           about.AboutSerialNumber = "0001";

           // get the company name from the assembly information
           {
              about.AboutCompanyName = Application.CompanyName.Trim();
           }

           about.ShowDialog();
        }
    }
}
