﻿//***************************************************************************
// (C) 2011 Avery Weigh-Tronix, LLC. 
//***************************************************************************
// TITLE: Opos.cs 
// DESCR: A C# port of the original OPOS C++ header include file Opos.h 
//        The project was written in C# using Visual Studio 2008, x86 target
//        platform, and .NET 2.0 on a Windows 7 (64-bit) computer.
//
// (C)Copyright 2011 Avery Weigh-Tronix, LLC.
//
// Contacts:
// Sales:	sales@salterbrecknell.com
//       	1-800-637-0529
//
// Service:	service@salterbrecknell.com
//      	1-800-242-2807
//
// Disclaimer:
// This test/demo program is provided as a courtesy to customers of Avery 
// Weigh-Tronix for their personal use.
//
// NO WARRANTIES: The free-of-charge software is provided “as-is” with no 
// warranties expressed or implied.
// NO LIABILITY: To the maximum extent permitted by applicable law, in no 
// event shall Avery Weigh-Tronix, its' suppliers or subsidiaries be liable 
// for any damages whatsoever (including without limitation, damages for 
// loss of business profits, business interruption, loss of business infor-
// mation, or other pecuniary loss) arising out of the installation, use or
// inability to use the software provided, even if Avery Weigh-Tronix has 
// been advised of the possibility of such damages.
// 
// This product was developed for Avery Weigh-Tronix by:
// www.vtxpro.com 
// (C)2011 Vertex Programming -- Santa Rosa, CA
//

#region Original Opos.h Title Block
/////////////////////////////////////////////////////////////////////
//
// Opos.h
//
// General header file for OPOS Applications.
//
// Modification history
// ------------------------------------------------------------------
// 95-12-08 OPOS Release 1.0                                     CRM
// 97-06-04 OPOS Release 1.2                                     CRM
//   Add OPOS_FOREVER.
//   Add BinaryConversion values.
// 98-03-06 OPOS Release 1.3                                     CRM
//   Add CapPowerReporting, PowerState, and PowerNotify values.
//   Add power reporting values for StatusUpdateEvent.
// 00-09-24 OPOS Release 1.5                                     CRM
//   Add OpenResult status values.
//
/////////////////////////////////////////////////////////////////////
#endregion

using System;
using System.Collections.Generic;
using System.Text;

namespace WTScaleSO_Test
{
    public static class Opos
    {
        /////////////////////////////////////////////////////////////////////
        // OPOS "State" Property Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_S_CLOSED = 1;
        public const long OPOS_S_IDLE = 2;
        public const long OPOS_S_BUSY = 3;
        public const long OPOS_S_ERROR = 4;


        /////////////////////////////////////////////////////////////////////
        // OPOS "ResultCode" Property Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_SUCCESS = 0;
        public const long OPOS_E_CLOSED = 101;
        public const long OPOS_E_CLAIMED = 102;
        public const long OPOS_E_NOTCLAIMED = 103;
        public const long OPOS_E_NOSERVICE = 104;
        public const long OPOS_E_DISABLED = 105;
        public const long OPOS_E_ILLEGAL = 106;
        public const long OPOS_E_NOHARDWARE = 107;
        public const long OPOS_E_OFFLINE = 108;
        public const long OPOS_E_NOEXIST = 109;
        public const long OPOS_E_EXISTS = 110;
        public const long OPOS_E_FAILURE = 111;
        public const long OPOS_E_TIMEOUT = 112;
        public const long OPOS_E_BUSY = 113;
        public const long OPOS_E_EXTENDED = 114;

        public const long OPOSERR = 100; // Base for ResultCode errors.
        public const long OPOSERREXT = 200; // Base for ResultCodeExtendedErrors.


        /////////////////////////////////////////////////////////////////////
        // OPOS "OpenResult" Property Constants
        /////////////////////////////////////////////////////////////////////

        // The following can be set by the control object.
        public const long OPOS_OR_ALREADYOPEN = 301;
        // Control Object already open.
        public const long OPOS_OR_REGBADNAME = 302;
        // The registry does not contain a key for the specified
        // device name.
        public const long OPOS_OR_REGPROGID = 303;
        // Could not read the device name key's default value, or
        // could not convert this Prog ID to a valid Class ID.
        public const long OPOS_OR_CREATE = 304;
        // Could not create a service object instance, or
        // could not get its IDispatch interface.
        public const long OPOS_OR_BADIF = 305;
        // The service object does not support one or more of the
        // method required by its release.
        public const long OPOS_OR_FAILEDOPEN = 306;
        // The service object returned a failure status from its
        // open call, but doesn't have a more specific failure code.
        public const long OPOS_OR_BADVERSION = 307;
        // The service object major version number is not 1.

        // The following can be returned by the service object if it
        // returns a failure status from its open call.
        public const long OPOS_ORS_NOPORT = 401;
        // Port access required at open, but configured port
        // is invalid or inaccessible.
        public const long OPOS_ORS_NOTSUPPORTED = 402;
        // Service Object does not support the specified device.
        public const long OPOS_ORS_CONFIG = 403;
        // Configuration information error.
        public const long OPOS_ORS_SPECIFIC = 450;
        // Errors greater than this value are SO-specific.


        /////////////////////////////////////////////////////////////////////
        // OPOS "BinaryConversion" Property Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_BC_NONE = 0;
        public const long OPOS_BC_NIBBLE = 1;
        public const long OPOS_BC_DECIMAL = 2;


        /////////////////////////////////////////////////////////////////////
        // "CheckHealth" Method: "Level" Parameter Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_CH_INTERNAL = 1;
        public const long OPOS_CH_EXTERNAL = 2;
        public const long OPOS_CH_INTERACTIVE = 3;


        /////////////////////////////////////////////////////////////////////
        // OPOS "CapPowerReporting", "PowerState", "PowerNotify" Property
        //   Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_PR_NONE = 0;
        public const long OPOS_PR_STANDARD = 1;
        public const long OPOS_PR_ADVANCED = 2;

        public const long OPOS_PN_DISABLED = 0;
        public const long OPOS_PN_ENABLED = 1;

        public const long OPOS_PS_UNKNOWN = 2000;
        public const long OPOS_PS_ONLINE = 2001;
        public const long OPOS_PS_OFF = 2002;
        public const long OPOS_PS_OFFLINE = 2003;
        public const long OPOS_PS_OFF_OFFLINE = 2004;


        /////////////////////////////////////////////////////////////////////
        // "ErrorEvent" Event: "ErrorLocus" Parameter Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_EL_OUTPUT = 1;
        public const long OPOS_EL_INPUT = 2;
        public const long OPOS_EL_INPUT_DATA = 3;


        /////////////////////////////////////////////////////////////////////
        // "ErrorEvent" Event: "ErrorResponse" Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_ER_RETRY = 11;
        public const long OPOS_ER_CLEAR = 12;
        public const long OPOS_ER_CONTINUEINPUT = 13;


        /////////////////////////////////////////////////////////////////////
        // "StatusUpdateEvent" Event: Common "Status" Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_SUE_POWER_ONLINE = 2001;
        public const long OPOS_SUE_POWER_OFF = 2002;
        public const long OPOS_SUE_POWER_OFFLINE = 2003;
        public const long OPOS_SUE_POWER_OFF_OFFLINE = 2004;


        /////////////////////////////////////////////////////////////////////
        // General Constants
        /////////////////////////////////////////////////////////////////////

        public const long OPOS_FOREVER = -1;
    }
}
